def measure_of_movement():
    """
    m1 : 1st moment Σx/n ~= mean or x_bar
    m2 : 2nd moment Σ(x - x_bar)^2/n ~ Variance (for Population)
    m3 : 3rd moment Σ(x - x_bar)^3/n
    m4 : 4th moment Σ(x - x_bar)^4/n
    """


def kurtosis():
    """
    Please refer to measure_of_movement.__doc__ for ms
    ---
    K = m4 / (m2 ^ 2)
    """


def skewness():
    """
    Please refer to measure_of_movement.__doc__ for ms
    ---
    G = m3 / sqrt(m2 ^ 3)
    """
